=== modified file 'bzrlib/hashcache.py'
--- bzrlib/hashcache.py	2005-12-01 17:36:29 +0000
+++ bzrlib/hashcache.py	2006-01-11 20:15:05 +0000
@@ -37,7 +37,6 @@
 from bzrlib.atomicfile import AtomicFile
 from bzrlib.osutils import pathjoin
 
-
 FP_MODE_COLUMN = 5
 
 def _fingerprint(abspath):

=== modified file 'bzrlib/tests/test_hashcache.py'
--- bzrlib/tests/test_hashcache.py	2005-12-26 05:28:38 +0000
+++ bzrlib/tests/test_hashcache.py	2006-01-12 01:26:36 +0000
@@ -36,6 +36,10 @@
     start = int(time.time())
     while int(time.time()) == start:
         time.sleep(0.2)
+
+
+class FixThisError(Exception):
+    pass
     
 
 class TestHashCache(TestCaseInTempDir):
@@ -118,3 +122,28 @@
         self.assertEquals(hc.hit_count, 1)
         self.assertEquals(hc.miss_count, 0)
         self.assertEquals(hc.get_sha1('foo2'), sha1('new content'))
+
+    def test_hashcache_raise(self):
+        """check that hashcache can raise BzrError"""
+        from bzrlib.hashcache import HashCache
+        import os
+
+        os.mkdir('.bzr')
+        hc = HashCache(u'.')
+        ok = False
+
+        # make a best effort to create a weird kind of file
+        funcs = (os.mkfifo, os.mknod)
+        for func in funcs:
+            try:
+                func('a')
+                ok = True
+                break
+            except FixThisError:
+                pass
+
+        from bzrlib.errors import BzrError
+        if ok:
+            self.assertRaises(BzrError, hc.get_sha1, 'a')
+        else:
+            raise BzrError("no weird file type could be created: extend this test case for your os")

